==> qtjambi-charts-debuginfo-macos-5.15.20.jar: sources/QtJambiCharts/QVCandlestickModelMapper_shell.h <==
#ifndef QVCANDLESTICKMODELMAPPER_SHELL_H
#define QVCANDLESTICKMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qvcandlestickmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qcandlestickseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QVCandlestickModelMapper_shell : public QtCharts::QVCandlestickModelMapper, public QtJambiShellInterface
{
public:
    QVCandlestickModelMapper_shell(QObject* parent0 = nullptr);
    ~QVCandlestickModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientation orientation() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVCandlestickModelMapper_access : public QtCharts::QVCandlestickModelMapper
{
    jint __qt_orientation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QVCANDLESTICKMODELMAPPER_SHELL_H

==> qtjambi-charts-debuginfo-macos-6.5.3.jar: sources/QtJambiCharts/QVCandlestickModelMapper_shell.h <==
#ifndef QVCANDLESTICKMODELMAPPER_SHELL_H
#define QVCANDLESTICKMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qvcandlestickmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qcandlestickseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QVCandlestickModelMapper_shell : public QVCandlestickModelMapper, public QtJambiShellInterface
{
public:
    QVCandlestickModelMapper_shell(QObject* parent0 = nullptr);
    ~QVCandlestickModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientation orientation() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVCandlestickModelMapper_access : public QVCandlestickModelMapper
{
    jint __qt_orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QVCANDLESTICKMODELMAPPER_SHELL_H
